@@ -1,15 +1,14 @@
 __all__ = ["SystemMonitor"]
 
 import asyncio
-from typing import Dict, Any
+from typing import Dict, Any, List
 
 import psutil  #  type: ignore
 from uptime import uptime  # type: ignore
 
 from yaqd_core import Sensor, logging
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.INFO)
+from .__version__ import __branch__
 
 
 def diskio():
@@ -26,6 +25,8 @@ def diskio():
 
 class SystemMonitor(Sensor):
     _kind = "system-monitor"
+    _version = "1.0.0" + f"+{__branch__}" if __branch__ else ""
+    traits: List[str] = []
     defaults: Dict[str, Any] = {}
 
     def __init__(self, name, config, config_filepath):
